@@ -80,6 +80,11 @@ PyDoc_STRVAR(compress_stream_doc,
 "----\n"
 "Compresses input_stream and writes the compressed data to output_stream, it\n"
 "doesn't close the streams.\n\n"
+"----\n"
+"DEPRECATION NOTICE\n"
+"The (de)compress_stream are deprecated and will be removed in a future version.\n"
+"See https://pyzstd.readthedocs.io/en/stable/deprecated.html for alternatives\n"
+"----\n\n"
 "If input stream is b'', nothing will be written to output stream.\n\n"
 "Return a tuple, (total_input, total_output), the items are int objects.\n\n"
 "Parameters\n"
@@ -344,6 +349,11 @@ PyDoc_STRVAR(decompress_stream_doc,
 "----\n"
 "Decompresses input_stream and writes the decompressed data to output_stream,\n"
 "it doesn't close the streams.\n\n"
+"----\n"
+"DEPRECATION NOTICE\n"
+"The (de)compress_stream are deprecated and will be removed in a future version.\n"
+"See https://pyzstd.readthedocs.io/en/stable/deprecated.html for alternatives\n"
+"----\n\n"
 "Supports multiple concatenated frames.\n\n"
 "Return a tuple, (total_input, total_output), the items are int objects.\n\n"
 "Parameters\n"
